@@ -10,7 +10,7 @@ from struct import pack # for network byte order
 # third party
 from mongrel2 import handler, request
 
-__version__ = '0.1.5'
+__version__ = '0.1.6'
 
 logger = logging.getLogger(__name__)
 
@@ -244,8 +244,13 @@ class Connection(handler.Connection):
             }
         )
 
-    def reply_to_http(self, req, *args, **kwargs):
+    def close_http(self, req, *args, **kwargs):
         """this is a wrapper around reply_http that also closes the connection"""
+
+        headers = kwargs.get('headers', {})
+        headers.setdefault('Connection', 'close')
+        kwargs['headers'] = headers
+
         r = self.reply_http(req, *args, **kwargs)
         self.close(req)
         return r
@@ -258,7 +263,7 @@ class Connection(handler.Connection):
             req.headers
         ))
 
-        self.reply_to_http(
+        self.close_http(
           req,
           body='',
           code=501,
